#
# spec file for package terraform-provider-google
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

%global repo            terraform-provider-google
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}
%global registry        registry.terraform.io
%global namespace       hashicorp
%global providername    google

%ifarch aarch64
%define terraformarch   amd64
%endif
%ifarch ppc64
%define terraformarch   ppc64
%endif
%ifarch ppc64le
%define terraformarch   ppc64le
%endif
%ifarch s390x
%define terraformarch   s390x
%endif
%ifarch %{ix86}
%define terraformarch   i386
%endif
%ifarch x86_64
%define terraformarch   amd64
%endif

%if 0%{?suse_version}
%{go_nostrip}
%endif

Name:           terraform-provider-google
Version:        3.43.0
Release:        6.3.1
Summary:        Terraform provider for Google Cloud Platform (GCP)
License:        MPL-2.0
Group:          System/Management
URL:            https://github.com/terraform-providers/terraform-provider-google
Source:         %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
%if 0%{?ubuntu_version}
BuildRequires:  debhelper
BuildRequires:  dh-golang
BuildRequires:  golang-go
BuildRequires:  libvirt-dev
BuildRequires:  pkgconfig
BuildRequires:  xz-utils
%else
Requires:       terraform >= 0.11.0
%if 0%{?fedora} || 0%{?rhel_version} || 0%{?centos_version}
BuildRequires:  golang
%endif
%if 0%{?suse_version}
BuildRequires:  golang(API) >= 1.13
BuildRequires:  golang-packaging
%endif
%endif
%if 0%{?suse_version}
%{go_provides}
%endif

%description
This is a terraform provider that lets you provision servers on Google Cloud
Platform via Terraform.

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}

%build
%{goprep} %{import_path}
%{gobuild} --mod=vendor "" ...

%install
%{goinstall}
rm -rf %{buildroot}/%{_libdir}/go/contrib
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/%{name}_v%{version}
install -d 755 %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}
ln -s %{_bindir}/%{name} %{buildroot}%{_datadir}/terraform/providers/%{registry}/%{namespace}/%{providername}/%{version}/linux_%{terraformarch}/%{name}_v%{version}

%files
%license LICENSE
%doc CHANGELOG.md README.md
%{_bindir}/%{name}
%{_bindir}/%{name}_v%{version}
%{_datadir}/terraform

%changelog
* Thu Nov 12 2020 adrian.glaubitz@suse.com
- Bump minimum Go API version to 1.13
* Wed Nov 11 2020 adrian.glaubitz@suse.com
- Add symbolic link to comply with new filesystem layout for local provider copies
- Define and use common Go spec file variables
* Mon Oct 19 2020 adrian.glaubitz@suse.com
- Update to version 3.43.0
  * FEATURES:
    + **New Data Source:** `google_pubsub_topic` (#7426)
    + **New Data Source:** `google_compute_global_forwarding_rule` (#7434)
    + **New Data Source:** `google_cloud_run_service` (#7388)
    + **New Resource:** `google_bigtable_table_iam_member` (#7410)
    + **New Resource:** `google_bigtable_table_iam_binding` (#7410)
    + **New Resource:** `google_bigtable_table_iam_policy` (#7410)
  * IMPROVEMENTS:
    + appengine: added ability to manage pre-firestore appengine applications. (#7408)
    + bigquery: added support for `google_bigquery_table` `materialized_view` field (#7080)
    + compute: Marked `google_compute_per_instance_config` as GA (#7429)
    + compute: Marked `google_compute_region_per_instance_config` as GA (#7429)
    + compute: Marked `stateful_disk` as GA in `google_compute_instance_group_manager` (#7429)
    + compute: Marked `stateful_disk` as GA in `google_compute_region_instance_group_manager` (#7429)
    + compute: added additional fields to the `google_compute_forwarding_rule` datasource. (#7437)
    + dns: added `forwarding_path` field to `google_dns_policy` resource (#7416)
    + netblock: changed `google_netblock_ip_ranges` to read from cloud.json file rather than DNS record (#7157)
  * BUG FIXES:
    + accessapproval: fixed issue where, due to a recent API change, `google_*_access_approval.enrolled_services.
    cloud_product` entries specified as a URL would result in a permadiff
    + bigquery: fixed an issue in `google_bigquery_job` where non-US locations could not be read (#7418)
    + cloudrun: fixed an issue in `google_cloud_run_domain_mapping` where labels provided by Google would cause a diff (#7407)
    + compute: Fixed an issue where `google_compute_region_backend_service`
    required `healthChecks` for a serverless network endpoint group. (#7433)
    + container: fixed `node_config.image_type` perma-diff when specified in lower case. (#7412)
    + datacatalog: fixed an error in `google_data_catalog_tag` when trying to set boolean field to `false` (#7409)
    + monitoring: fixed bug where deleting a `google_monitoring_dashboard` would give an "unsupported protocol scheme" error
  * See CHANGELOG.md for the previous changes from 2.20.2 to 3.42.0
* Thu Aug  6 2020 aosthof@suse.de
- Inclusion in SLES 15 SP1/SP2 Public Cloud Module (jsc#ECO-2340)
* Mon Jul 20 2020 adrian.glaubitz@suse.com
- Update to version 2.20.3:
  * NOTES:
    + `2.20.3` is a backport release, and some changes will not appear
    in `3.X` series releases until `3.12.0`.
    To upgrade to `3.X` you will need to perform a large jump in versions,
    and it is _strongly_ advised that you attempt to upgrade to `3.X`
    instead of using this release.
    + `2.20.3` is primarily a preventative fix, in anticipation of a change
    in API response messages adding a default value.
  * BUG FIXES:
    + compute: fixed error when reading `google_compute_instance_template`
    resources with `network_interface[*].name` set. (#5812)
  * See CHANGELOG.md for the previous changes from 1.19.0 to 2.20.2
- Enable vendoring in _service file
- Disable services in _service file as they currently cause issues
  with OBS, run services manually and include tarballs
- Raise minimum Golang API version to 1.12 in BuildRequires
- Switch tarball compression to gzip as the vendoring service currently
  does not support the xz compression format
* Fri Sep 21 2018 ldevulder@suse.de
- Update to version 1.18.0:
  * v1.18.0
  * Add tests based on google_compute_address examples. (#2017)
  * move all remaining import_ tests into resource-specific tests (#2060)
  * Reduce rig datasource test target size to 1. (#2064)
  * just make sweeper warn instead of error (#2057)
  * change delay in region instance group data source test (#2047)
  * get dataproc logs when jobs fail in test (#2049)
  * Add missing quotation marks to compute_ssl_certificate tests (#2042)
  * Fix Composer Test flakes/bucket sweeper (#2052)
  * Remove hardcoded version in resource_container_node_pool_test.go (#2046)
* Thu Aug 30 2018 opensuse-packaging@opensuse.org
- Update to version 1.17.0+git20180829.ca031703:
  * Update CHANGELOG.md
  * Fixes for importing sql database instances (#1956)
  * Magic Modules changes. (#1951)
  * Use beta API location for google_container_engine_versions (#1939)
  * Autogenerate HealthCheck resource (#1941)
  * fix possible error from nil check (#1942)
  * Fix service account key data source name (#1932)
  * Force acceptance test failure if .Set errors (#1934)
  * Ignore google provider binary (#1935)
  * Initial TF commits needed for cloud composer support (#1926)
* Thu Jul  5 2018 opensuse-packaging@opensuse.org
- Update to version 1.15.0+git20180702.064ec03:
  * Added ability to configure resource labels on a GKE cluster
  * Type conversion issue
  * Minor code changes as requested
  * Update CHANGELOG.md
  * Update CHANGELOG.md
  * Update redis example to actually use network (#1720)
  * add `quic_override` to `google_compute_target_https_proxy` (#1718)
  * Update CHANGELOG.md
  * Autogenerate VPN Tunnel resource (#1699)
  * Support Redis configuration (#1706)
  * Update CHANGELOG.md
  * Update CHANGELOG.md
* Wed Jul  4 2018 ldevulder@suse.com
- Initial release
